import "./tasks/fastqc.wdl" as fastqc
import "./tasks/fastqscreen.wdl" as fastqscreen
import "./tasks/bamqc.wdl" as bamqc
import "./tasks/benchmark.wdl" as benchmark
import "./tasks/multiqc.wdl" as multiqc

workflow {{ project_name }} {

	File inputSamplesFile
	Array[Array[File]] inputSamples = read_tsv(inputSamplesFile)
	File screen_ref_dir
	File fastq_screen_conf
	File benchmarking_dir
	File ref_dir
	String fasta

	scatter (sample in inputSamples){
		call fastqc.fastqc as fastqc {
			input:
			read1=sample[0],
			read2=sample[1]
		}

		call fastqscreen.fastq_screen as fastqscreen {
			input:
			read1=sample[0],
			read2=sample[1],
			screen_ref_dir=screen_ref_dir,
			fastq_screen_conf=fastq_screen_conf
		}

		call bamqc.bamqc as bamqc {
			input:
			bam=sample[2],
			bai=sample[3]
		}

		call benchmark.benchmark as benchmark {
			input:
			vcf=sample[4],
			benchmarking_dir=benchmarking_dir,
			ref_dir=ref_dir,
			sample_mark=sample[5],
			fasta=fasta
		}
	}
	call multiqc.multiqc as multiqc {
		input:
		read1_zip=fastqc.read1_zip,
		read2_zip=fastqc.read2_zip,
		txt1=fastqscreen.txt1,
		txt2=fastqscreen.txt2,
		genome_result=bamqc.genome_result,
		coverage=bamqc.coverage,
		insert_size=bamqc.insert_size,
		genome_fraction=bamqc.genome_fraction,
		gc_dist=bamqc.gc_dist,
		summary=benchmark.summary
	}

}

